pygeodesy.ltp.ChLV

Package pygeodesy :: Module ltp :: Class ChLV |
[frames] | no frames]

# Class ChLV

                  object --+
                           |
                       _ChLV --+
                               |
      object --+               |
               |               |
    named._Named --+           |
                   |           |
    named._NamedBase --+       |
                       |       |
          LocalCartesian --+   |
                           |   |
                         Ltp --+
                               |
                              ChLV

Conversion between WGS84 geodetic and Swiss projection coordinates using pygeodesy.EcefKarney's Earth-Centered, Earth-Fixed (ECEF) methods.

See Also: Swiss projection formulas, page 7ff, NAVREF, REFRAME and SwissTopo Scripts GPS WGS84 <-> LV03.

Instance Methods
__init__(self, latlonh0=Bern(lat=46.952406, lon=7.439583, height=49.55, datum=Datum(na`...`, **other_Ltp_kwds) New ECEF-based WGS84-Swiss ChLV converter, centered at Bern, Ch. |
forward(self, latlonh, lon=None, height=0, M=None, **name) Convert WGS84 geodetic to Swiss projection coordinates. |
reverse(self, enh_, n=None, h_=0, M=None, **name) Convert Swiss projection to WGS84 geodetic coordinates. |
Inherited from `LocalCartesian`: `__eq__`, `reset`, `toStr` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
false2(Y, X, LV95=True, **name) Add the Swiss LV95 or LV03 falsing. |
isLV03(e, n) Is `(e, n)` a valid Swiss LV03 projection? |
isLV95(e, n, raiser=True) Is `(e, n)` a valid Swiss LV95 or LV03 projection? |
unfalse2(e, n, LV95=None, **name) Remove the Swiss LV95 or LV03 falsing. |

Class Variables
| Bern = `Bern(lat=46.952406, lon=7.439583, height=49.55, datum=D`...``

Properties
Inherited from `Ltp`: `ecef` Inherited from `LocalCartesian`: `M`, `datum`, `ellipsoid`, `height0`, `lat0`, `latlonheight0`, `lon0`, `lon00` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, latlonh0=Bern(lat=46.952406, lon=7.439583, height=49.55, datum=Datum(na`...`, **other_Ltp_kwds) (Constructor) |
New ECEF-based WGS84-Swiss ChLV converter, centered at Bern, Ch. Arguments: `latlonh0` - The geodetic origin and height, overriding `Bern, Ch`. `other_Ltp_kwds` - Optional, other Ltp.__init__ keyword arguments. Raises: `TypeError` - Invalid `ecef`. Overrides: object.__init__ See Also: Ltp.__init__ for more information.

### forward (self, latlonh, lon=None, height=0, M=None, **name) |
Convert WGS84 geodetic to Swiss projection coordinates. Must be overloaded. Arguments: `latlonh` - Either a `LatLon`, Ltp or `scalar` (geodetic) latitude (`degrees`). `lon` - Optional, `scalar` (geodetic) longitude (`degrees`) iff `latlonh` is `scalar`, ignored otherwise. `height` - Optional, height, vertically above (or below) the surface of the ellipsoid (`meter`) iff `latlonh` and `lon` are `scalar`, ignored otherwise. `M` - If `True`, return the concatenated rotation EcefMatrix iff available and for `ChLV` only, `None` otherwise (`bool`). `name` - Optional `name=NN` (`str`). Returns: A ChLV9Tuple`(Y, X, h_, lat, lon, height, ltp, ecef, M)` with the unfalsed Swiss Y, X coordinates, Swiss h_ height, the given geodetic `lat`, `lon` and `height`, `ecef` (Ecef9Tuple) at Bern, Ch, rotation matrix `M` and `ltp` this `ChLV`, `ChLVa` or `ChLVe` instance. Raises: `LocalError` - Invalid or non-`scalar` `latlonh`, `lon` or `height`. Overrides: LocalCartesian.forward (inherited documentation)

### reverse (self, enh_, n=None, h_=0, M=None, **name) |
Convert Swiss projection to WGS84 geodetic coordinates. Arguments: `enh_` - A Swiss projection (ChLV9Tuple) or the `scalar`, falsed Swiss E_LV95 or y_LV03 easting (`meter`). `n` - Falsed Swiss N_LV85 or x_LV03 northing (`meter`) iff `enh_` is `scalar`, ignored otherwise. `h_` - Swiss h' height (`meter`) iff `enh_` and `n` are `scalar`, ignored otherwise. `M` - If `True`, return the concatenated rotation EcefMatrix iff available and for `ChLV` only, `None` otherwise (`bool`). `name` - Optional `name=NN` (`str`). Returns: A ChLV9Tuple`(Y, X, h_, lat, lon, height, ltp, ecef, M)` with the unfalsed Swiss Y, X coordinates, Swiss h_ height, the given geodetic `lat`, `lon` and `height`, `ecef` (Ecef9Tuple) at Bern, Ch, rotation matrix `M` and `ltp` this `ChLV`, `ChLVa` or `ChLVe` instance. Raises: `LocalError` - Invalid or non-`scalar` `enh_`, `n` or `h_`. Overrides: LocalCartesian.reverse (inherited documentation)

### false2 (Y, X, LV95=True, **name) Static Method |
Add the Swiss LV95 or LV03 falsing. Arguments: `Y` - Unfalsed Swiss Y easting (`meter`). `X` - Unfalsed Swiss X northing (`meter`). `LV95` - If `True`, add `LV95` falsing, if `False` add `LV03` falsing, otherwise leave unfalsed. `name` - Optional `name=NN` (`str`). Returns: A ChLVEN2Tuple`(E_LV95, N_LV95)` or a ChLVyx2Tuple`(y_LV03, x_LV03)` with falsed `Y` and `X`, otherwise a ChLVYX2Tuple`(Y, X)` with `Y` and `X` as-is.

### isLV03 (e, n) Static Method |
Is `(e, n)` a valid Swiss LV03 projection? Arguments: `e` - Falsed (or unfalsed) Swiss easting (`meter`). `n` - Falsed (or unfalsed) Swiss northing (`meter`). Returns: `True` if `(e, n)` is a valid, falsed Swiss LV03, projection `False` otherwise.

### isLV95 (e, n, raiser=True) Static Method |
Is `(e, n)` a valid Swiss LV95 or LV03 projection? Arguments: `e` - Falsed (or unfalsed) Swiss easting (`meter`). `n` - Falsed (or unfalsed) Swiss northing (`meter`). `raiser` - If `True`, throw a LocalError if `e` and `n` are invalid Swiss LV95 nor LV03. Returns: `True` or `False` if `(e, n)` is a valid Swiss LV95 respectively LV03 projection, `None` otherwise.

### unfalse2 (e, n, LV95=None, **name) Static Method |
Remove the Swiss LV95 or LV03 falsing. Arguments: `e` - Falsed Swiss E_LV95 or y_LV03 easting (`meter`). `n` - Falsed Swiss N_LV95 or x_LV03 northing (`meter`). `LV95` - If `True`, remove LV95 falsing, if `False` remove LV03 falsing, otherwise use method `isLV95(e, n)`. `name` - Optional `name=NN` (`str`). Returns: A ChLVYX2Tuple`(Y, X)` with the unfalsed `e` respectively `n`.

Class Variable Details

  ### Bern Value:
      Bern(lat=46.952406, lon=7.439583, height=49.55, datum=Datum(name='WGS8
      4', ellipsoid=Ellipsoids.WGS84, transform=Transforms.WGS84))